==> apache-beam-2.41.0-source-release.zip: beam-2.41.0/sdks/java/io/amazon-web-services2/src/test/java/org/apache/beam/sdk/io/aws2/options/SerializationTestUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.io.aws2.options;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.beam.sdk.util.common.ReflectHelpers;

public class SerializationTestUtil {

  private static final ObjectMapper MAPPER =
      (new ObjectMapper())
          .registerModules(ObjectMapper.findModules(ReflectHelpers.findClassLoader()));

  public static <T> T serializeDeserialize(Class<T> clazz, T obj) {
    try {
      String jsonString = MAPPER.writeValueAsString(obj);
      return MAPPER.readValue(jsonString, clazz);
    } catch (JsonProcessingException e) {
      throw new RuntimeException("Failed to serialize/deserialize " + clazz.getSimpleName(), e);
    }
  }
}

==> apache-beam-2.70.0-source-release.zip: beam-2.70.0/sdks/java/io/amazon-web-services2/src/test/java/org/apache/beam/sdk/io/aws2/options/SerializationTestUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.io.aws2.options;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.beam.sdk.util.common.ReflectHelpers;

public class SerializationTestUtil {

  private static final ObjectMapper MAPPER =
      (new ObjectMapper())
          .registerModules(ObjectMapper.findModules(ReflectHelpers.findClassLoader()));

  public static <T> T serializeDeserialize(Class<T> clazz, T obj) {
    return deserialize(serialize(obj), clazz);
  }

  public static <T> String serialize(T obj) {
    try {
      return MAPPER.writeValueAsString(obj);
    } catch (JsonProcessingException e) {
      throw new RuntimeException("Failed to serialize " + obj.getClass().getSimpleName(), e);
    }
  }

  public static <T> T deserialize(String jsonString, Class<T> clazz) {
    try {
      return MAPPER.readValue(jsonString, clazz);
    } catch (JsonProcessingException e) {
      throw new RuntimeException("Failed to deserialize " + clazz.getSimpleName(), e);
    }
  }
}
